OrderedCrossover

Struct OrderedCrossover 

pub struct OrderedCrossover {
    pub crossover_rate: f64,
}
Ordered Crossover (OX)

The ordered crossover operator (OX) is a crossover operator for permutation-based chromosomes. It maintains the relative order of the elements in the parent chromosomes. With the crossover_rate probability it chooses two points in the parents, maintain the elements between the points and fill the remaining positions with the elements of the other parent in the order they appear.

Fields

crossover_rate: f64

Implementations

Source

impl OrderedCrossover

pub fn apply_ox( parent1: &mut Vec<i64>, parent2: &mut Vec<i64>, start: usize, end: usize, )